@@ -1,6 +1,7 @@
 import itertools
 import multiprocessing as mp
 import os
+import pandas as pd
 import re
 
 from tqdm import tqdm
@@ -32,10 +33,9 @@ class Experiment:
         results = {}
 
         for config in self.config_iterator:
-            trial_id = self.config_iterator._trial_id(config)
-            trial_dir = os.path.join(self.logdir, trial_id)
+            trial_id, trial_dir = self._get_trial(config)
 
-            range_num_samples = self._run_ids(trial_dir, num_samples)
+            range_num_samples = self._get_run_ids(trial_dir, num_samples)
 
             trial_configs = []
             for i, j in enumerate(range_num_samples):
@@ -56,10 +56,39 @@ class Experiment:
 
         return results
 
+    def report_mean_std(self, metric, extension="csv"):
+        results = {}
 
-    def _run_ids(self, trial_dir, num_samples):
-        previous_run_dirs = [
-            path for path in os.listdir(trial_dir) if re.search(r"run\d+$", path)
+        for config in self.config_iterator:
+            trial_id, trial_dir = self._get_trial(config)
+
+            data = []
+            for run in self._get_run_dirs(trial_dir):
+                filepath = os.path.join(trial_dir, run, f"{metric}.{extension}")
+                if os.path.isfile(filepath):
+                    data.append(pd.read_csv(filepath))
+
+            if data:
+                data = pd.concat(data)
+                data = data.groupby(data.index, sort=False)
+                results[trial_id] = (data.mean(), data.std())
+
+        return results
+
+    def _get_trial(self, config):
+        trial_id = self.config_iterator._trial_id(config)
+        trial_dir = os.path.join(self.logdir, trial_id)
+        return trial_id, trial_dir
+
+    @classmethod
+    def _get_run_dirs(cls, trial_dir):
+        return [
+            path for path in os.listdir(trial_dir)
+            if re.search(r"run\d+$", path)
         ]
+
+    @classmethod
+    def _get_run_ids(cls, trial_dir, num_samples):
+        previous_run_dirs = cls._get_run_dirs(trial_dir)
         start_id = len(previous_run_dirs)
         return range(start_id, start_id + num_samples)
